==> geeklog-1.5.0-jp-extended-1.1.tar.gz: geeklog-1.5.0-jp-extended-1.1/plugins/sitemap/language/japanese.php <==
<?php

// +---------------------------------------------------------------------------+
// | Sitemap Plugin for Geeklog - The Ultimate Weblog                          |
// +---------------------------------------------------------------------------+
// | geeklog/plugins/sitemap/language/japanese.php                             |
// +---------------------------------------------------------------------------+
// | Copyright (C) 2007-2008 mystral-kk - geeklog AT mystral-k DOT net         |
// |                                                                           |
// | Constructed with the Universal Plugin                                     |
// | Copyright (C) 2002 by the following authors:                              |
// | Tom Willett                 -    twillett@users.sourceforge.net           |
// | Blaine Lang                 -    langmail@sympatico.ca                    |
// | The Universal Plugin is based on prior work by:                           |
// | Tony Bibbs                  -    tony@tonybibbs.com                       |
// +---------------------------------------------------------------------------|
// | This program is free software; you can redistribute it and/or             |
// | modify it under the terms of the GNU General Public License               |
// | as published by the Free Software Foundation; either version 2            |
// | of the License, or (at your option) any later version.                    |
// |                                                                           |
// | This program is distributed in the hope that it will be useful,           |
// | but WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
// | GNU General Public License for more details.                              |
// |                                                                           |
// | You should have received a copy of the GNU General Public License         |
// | along with this program; if not, write to the Free Software               |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA|
// |                                                                           |
// +---------------------------------------------------------------------------|

$LANG_CHARSET = 'euc-jp';

$LANG_SMAP = array(
    'plugin'            => 'sitemapץ饰',
	'access_denied'     => 'ϵݤޤ',
	'access_denied_msg' => 'Υڡ˥ǤΤϡRoot桼ǤʤΥ桼̾IPɥ쥹ϵϿޤ',
	'admin'		        => 'sitemapץ饰',
	'install_header'	=> 'sitemapץ饰Υ󥹥ȡ/󥤥󥹥ȡ',
	'install_success'	=> 'sitemapץ饰Υ󥹥ȡޤ',
	'install_fail'  	=> 'sitemapץ饰Υ󥹥ȡ˼Ԥޤܺ٤ϥ顼(error.log)',
	'uninstall_success'	=> 'sitemapץ饰Υ󥤥󥹥ȡޤ',
	'uninstall_fail'    => 'sitemapץ饰Υ󥤥󥹥ȡ˼Ԥޤܺ٤ϥ顼(error.log)',
	'uninstall_msg'		=> 'sitemapץ饰ϥ󥤥󥹥ȡ뤵ޤ',
	'menu_label'        => 'ȥޥå',
	'sitemap'           => 'ȥޥå',
	'submit'            => '',
	'all'               => '٤',
	'article'           => '',
	'comments'          => '',
	'trackback'         => 'ȥåХå',
	'staticpages'       => 'Ūڡ',
	'calendar'          => '',
	'links'             => '',
	'polls'             => '󥱡',
	'dokuwiki'          => 'DokuWiki',
	'forum'             => 'Ǽ',
	'filemgmt'          => 'ե',
	'faqman'            => 'FAQ',
	'mediagallery'      => 'ǥ',
	'sitemap_setting'   => 'ȥޥåפ',
	'sitemap_setting_misc' => 'ȥޥåפɽ',
	'order'             => 'ɽ',
	'up'                => '',
	'down'              => '',
	'anon_access'       => 'ȥ桼ΥĤ',
	'sitemap_in_xhtml'  => 'XHTMLǺ',
	'date_format'       => 'դη',
	'desc_date_format'  => 'դηפǻѤѥ᡼ϡPHP<a href="http://www.php.net/manual/ja/function.date.php">date()ؿ</a>formatѥ᡼ƱǤ',
	'sitemap_items'     => 'ȥޥåפ˷Ǻܤ',
	'gsmap_setting'     => 'Googleȥޥåפ',
	'file_creation'     => 'ե',
	'google_sitemap_name' => 'ե̾',
	'time_zone'         => 'ॾ',
	'update_now'        => 'ޤ',
	'last_updated'      => '󹹿',
	'unknown'           => '',
	'desc_filename'     => '<strong>֥ե̾</strong>ˤϡGoogleȥޥåפΥե̾ꤷޤߥǶڤäʣǤޤХѤΥȥޥå̾ mobile.xml ȤƤ',
	'desc_time_zone'    => '<strong>֥ॾ</strong>ˤϡGeeklog֤Ƥ륵ФΥॾ<a href="http://ja.wikipedia.org/wiki/ISO_8601">ISO 8601</a>η((+|-)hh:mm)ǻꤷޤ㡧+09:00ˡ+01:00ʥѥˡ+01:00ʥ٥ˡ+00:00ʥɥˡ-05:00ʥ˥塼衼ˡ-08:00ʥ󥸥륹',
	'gsmap_items'       => 'Googleȥޥåפ˷Ǻܤ',
	'item_name'         => '̾',
	'freq'              => 'ֳ',
	'always'            => '˹',
	'hourly'            => '1֤1󹹿',
	'daily'             => '11󹹿',
	'weekly'            => '1֤1󹹿',
	'monthly'           => '11󹹿',
	'yearly'            => '1ǯ1󹹿',
	'never'             => 'ʤ',
	'priority'          => 'ͥ',
	'desc_freq'         => '<strong>ֳֹ֡</strong>ϡܤɤ줯餤٤ǹ뤫Ȥ褽ܰ¤GoogleΥ˻ؼޤֹʤפ򤷤Ƥ⡢GoogleΥϤȤɤ󤷤Ƥޤ',
	'desc_priority'     => '<strong>ͥ١</strong>ϡܤͥ٤<strong>0.0</strong>ʺˤ<strong>1.0</strong>ʺǹˤϰϤǻꤷƤͤ<strong>0.5</strong>Ǥ',
);

==> geeklog-1.7.1-jp-extended-1.1.tar.gz: geeklog-1.7.1-jp-extended-1.1/plugins/sitemap/language/japanese.php <==
<?php

// +---------------------------------------------------------------------------+
// | Sitemap Plugin for Geeklog - The Ultimate Weblog                          |
// +---------------------------------------------------------------------------+
// | geeklog/plugins/sitemap/language/japanese.php                             |
// +---------------------------------------------------------------------------+
// | Copyright (C) 2007-2008 mystral-kk - geeklog AT mystral-k DOT net         |
// |                                                                           |
// | Constructed with the Universal Plugin                                     |
// | Copyright (C) 2002 by the following authors:                              |
// | Tom Willett                 -    twillett@users.sourceforge.net           |
// | Blaine Lang                 -    langmail@sympatico.ca                    |
// | The Universal Plugin is based on prior work by:                           |
// | Tony Bibbs                  -    tony@tonybibbs.com                       |
// +---------------------------------------------------------------------------|
// | This program is free software; you can redistribute it and/or             |
// | modify it under the terms of the GNU General Public License               |
// | as published by the Free Software Foundation; either version 2            |
// | of the License, or (at your option) any later version.                    |
// |                                                                           |
// | This program is distributed in the hope that it will be useful,           |
// | but WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
// | GNU General Public License for more details.                              |
// |                                                                           |
// | You should have received a copy of the GNU General Public License         |
// | along with this program; if not, write to the Free Software               |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA|
// |                                                                           |
// +---------------------------------------------------------------------------|

if (strpos(strtolower($_SERVER['PHP_SELF']), 'japanese.php') !== FALSE) {
	die('This file cannot be used on its own.');
}

$LANG_SMAP = array(
    'plugin'            => 'sitemapץ饰',
	'access_denied'     => 'ϵݤޤ',
	'access_denied_msg' => 'Υڡ˥ǤΤϡRoot桼ǤʤΥ桼̾IPɥ쥹ϵϿޤ',
	'admin'		        => 'sitemapץ饰',
	'install_header'	=> 'sitemapץ饰Υ󥹥ȡ/󥤥󥹥ȡ',
	'install_success'	=> 'sitemapץ饰Υ󥹥ȡޤ',
	'install_fail'  	=> 'sitemapץ饰Υ󥹥ȡ˼Ԥޤܺ٤ϥ顼(error.log)',
	'uninstall_success'	=> 'sitemapץ饰Υ󥤥󥹥ȡޤ',
	'uninstall_fail'    => 'sitemapץ饰Υ󥤥󥹥ȡ˼Ԥޤܺ٤ϥ顼(error.log)',
	'uninstall_msg'		=> 'sitemapץ饰ϥ󥤥󥹥ȡ뤵ޤ',
	'menu_label'        => 'ȥޥå',
	'sitemap'           => 'ȥޥå',
	'submit'            => '',
	'all'               => '٤',
	'article'           => '',
	'comments'          => '',
	'trackback'         => 'ȥåХå',
	'staticpages'       => 'Ūڡ',
	'calendar'          => '',
	'links'             => '',
	'polls'             => '󥱡',
	'dokuwiki'          => 'DokuWiki',
	'forum'             => 'Ǽ',
	'filemgmt'          => 'ե',
	'faqman'            => 'FAQ',
	'mediagallery'      => 'ǥ',
	'calendarjp'        => 'jp',
	'download'          => '',
	'sitemap_setting'   => 'ȥޥåפ',
	'sitemap_setting_misc' => 'ȥޥåפɽ',
	'order'             => 'ɽ',
	'up'                => '',
	'down'              => '',
	'anon_access'       => 'ȥ桼ΥĤ',
	'sitemap_in_xhtml'  => 'XHTMLǺ',
	'date_format'       => 'դη',
	'desc_date_format'  => 'դηפǻѤѥ᡼ϡPHP<a href="http://www.php.net/manual/ja/function.date.php">date()ؿ</a>formatѥ᡼ƱǤ',
	'sitemap_items'     => 'ȥޥåפ˷Ǻܤ',
	'gsmap_setting'     => 'Googleȥޥåפ',
	'file_creation'     => 'ե',
	'google_sitemap_name' => 'ե̾',
	'time_zone'         => 'ॾ',
	'update_now'        => 'ޤ',
	'last_updated'      => '󹹿',
	'unknown'           => '',
	'desc_filename'     => '<strong>֥ե̾</strong>ˤϡGoogleȥޥåפΥե̾ꤷޤߥǶڤäʣǤޤХѤΥȥޥå̾ mobile.xml ȤƤ',
	'desc_time_zone'    => '<strong>֥ॾ</strong>ˤϡGeeklog֤Ƥ륵ФΥॾ<a href="http://ja.wikipedia.org/wiki/ISO_8601">ISO 8601</a>η((+|-)hh:mm)ǻꤷޤ㡧+09:00ˡ+01:00ʥѥˡ+01:00ʥ٥ˡ+00:00ʥɥˡ-05:00ʥ˥塼衼ˡ-08:00ʥ󥸥륹',
	'gsmap_items'       => 'Googleȥޥåפ˷Ǻܤ',
	'item_name'         => '̾',
	'freq'              => 'ֳ',
	'always'            => '˹',
	'hourly'            => '1֤1󹹿',
	'daily'             => '11󹹿',
	'weekly'            => '1֤1󹹿',
	'monthly'           => '11󹹿',
	'yearly'            => '1ǯ1󹹿',
	'never'             => 'ʤ',
	'priority'          => 'ͥ',
	'desc_freq'         => '<strong>ֳֹ֡</strong>ϡܤɤ줯餤٤ǹ뤫Ȥ褽ܰ¤GoogleΥ˻ؼޤֹʤפ򤷤Ƥ⡢GoogleΥϤȤɤ󤷤Ƥޤ',
	'desc_priority'     => '<strong>ͥ١</strong>ϡܤͥ٤<strong>0.0</strong>ʺˤ<strong>1.0</strong>ʺǹˤϰϤǻꤷƤͤ<strong>0.5</strong>Ǥ',
	
	// Since version 1.1.4
	'common_setting'    => '̤',
	'sp_setting'        => 'Ūڡ',
	'sp_type'           => 'ȥޥåפ˷Ǻܤ륿',
	'sp_type0'          => '٤',
	'sp_type1'          => '󥿡֥åɽڡΤ',
	'sp_type2'          => '󥿡֥åɽʤڡΤ',
	'sp_except'         => 'ڡIDɽġȾѥڡǶڤ',
);
